@@ -29,7 +29,7 @@ Usage::
     list_webhooks_paginator: ListWebhooksPaginator = client.get_paginator("list_webhooks")
     ```
 """
-from mypy_boto3_codepipeline.client import CodePipelineClient, CodePipelineClient as Client
+from mypy_boto3_codepipeline.client import CodePipelineClient
 from mypy_boto3_codepipeline.paginator import (
     ListActionExecutionsPaginator,
     ListActionTypesPaginator,
@@ -39,6 +39,8 @@ from mypy_boto3_codepipeline.paginator import (
     ListWebhooksPaginator,
 )
 
+Client = CodePipelineClient
+
 
 __all__ = (
     "Client",
